//////////////////////////////////////////////////////////////////////////////
// k13client.h
// -------------------
// K13 window decoration for KDE
// -------------------
// Copyright (c) 2003 David Johnson <david@usermode.org>
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
// IN THE SOFTWARE.
//////////////////////////////////////////////////////////////////////////////

#ifndef EXAMPLECLIENT_H
#define EXAMPLECLIENT_H

#include <kwin/kwinbutton.h>
#include <kwin/client.h>
#include <kpixmap.h>

class QSpacerItem;
class QPoint;

namespace KWinInternal {

enum ButtonType {
	ButtonHelp=0,
	ButtonMax,
	ButtonMin,
	ButtonClose, 
	ButtonMenu,
	ButtonSticky,
	ButtonTypeCount
};

// K13Handler /////////////////////////////////////////////////////////////

class K13Handler: public QObject
{
public:
	K13Handler();
	~K13Handler();
	void reset();

	static bool initialized();
	static unsigned contrast();
	static Qt::AlignmentFlags titleAlign();

private:
	void readConfig();

private:
	static bool initialized_;
	static Qt::AlignmentFlags titlealign_;
};

inline bool K13Handler::initialized()
	{ return initialized_; }

inline Qt::AlignmentFlags K13Handler::titleAlign()
	{ return titlealign_; }

// K13Button //////////////////////////////////////////////////////////////

class K13Button : public KWinInternal::KWinButton
{
public:
	K13Button(Client *parent, const char *name, const QString &tip,
				  ButtonType type, QPixmap *p1, QPixmap *p2, QPixmap *p3);
	~K13Button();

	void setCurrentPixmap(QPixmap *pix);
	QSize sizeHint() const;
	int lastMousePress() const;
	void reset();

private:
	void enterEvent(QEvent *e);
	void leaveEvent(QEvent *e);
	void mousePressEvent(QMouseEvent *e);
	void mouseReleaseEvent(QMouseEvent *e);
	void drawButton(QPainter *painter);

private:
	Client *client_;
	ButtonType type_;
	QPixmap *deco_;
	QPixmap *deco_off_;
	QPixmap *deco_on_;
	QPixmap *deco_click_;
	int lastmouse_;
};

inline int K13Button::lastMousePress() const
	{ return lastmouse_; }

inline void K13Button::reset()
	{ repaint(false); }

// K13Client //////////////////////////////////////////////////////////////

class K13Client : public KWinInternal::Client
{
	Q_OBJECT
public:
	K13Client(Workspace *ws, WId w, QWidget *parent = 0,
				  const char *name = 0);
	~K13Client();

private:
	QLabel* addPixLabel(QBoxLayout *opLayout, QString spPixName, QLabel **ppLabel, QWidget* opLabel, int align);
	//void addButtons(QBoxLayout* layout, const QString& buttons);

	void resizeEvent(QResizeEvent *e);
	void paintEvent(QPaintEvent *e);

	void mouseDoubleClickEvent(QMouseEvent *e);
	void captionChange(const QString &name);
	void maximizeChange(bool m);
	void stickyChange(bool s);
	void iconChange();
	void activeChange(bool a);
	MousePosition mousePosition(const QPoint &point) const;

private slots:
	void maxButtonPressed();
	void menuButtonPressed();

private:
	K13Button *button[ButtonTypeCount];
	QLabel *titlebar_;
};

} // namespace KWinInternal

#endif // EXAMPLECLIENT_H
